pitchtools.IntervalClassSegment
===============================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment

.. autoclass:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.count
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.custom_identifier
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.from_selection
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.has_duplicates
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.index
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.is_tertian
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.item_class
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__add__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__contains__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__eq__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__format__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__getitem__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__getslice__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__hash__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__iter__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__len__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__makenew__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__mul__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__ne__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__repr__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__rmul__
      ~abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__str__

Bases
-----

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.is_tertian
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.index
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassSegment.IntervalClassSegment.__str__
   :noindex:
